/*
* rawhide - find files using pretty C expressions
* https://raf.org/rawhide
* https://github.com/raforg/rawhide
* https://codeberg.org/raforg/rawhide
*
* Copyright (C) 1990 Ken Stauffer, 2022 raf <raf@raf.org>
*
* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 3 of the License, or
* (at your option) any later version.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with this program; if not, see <https://www.gnu.org/licenses/>.
*
* 20221011 raf <raf@raf.org>
*/

#ifndef RAWHIDE_RHDATA_H
#define RAWHIDE_RHDATA_H

void rawhide_init(void);
void rawhide_finish(void);
symbol_t *insert_symbol(char *name, int toktype, llong val);
symbol_t *locate_symbol(char *name);
symbol_t *locate_patmod_prefix(char *name);
int rawhide_instruction(void (*func)(llong), llong value);
llong rawhide_execute(void);

#endif
